@@ -1,11 +1,14 @@
 import itertools
 from typing import Dict, List
+import collections
 
 from tokenizer_tools.tagset.offset.analysis.express_pattern import \
     ExpressPattern
 from tokenizer_tools.tagset.offset.corpus import Corpus
+from tokenizer_tools.tagset.offset.analysis.read_markdown import read_markdown
 
 
+# TODO: PatternCorpus seems is a better name than this
 class CorpusPattern(Corpus):
     @classmethod
     def create_from_corpus(cls, corpus: Corpus) -> "CorpusPattern":
@@ -41,3 +44,24 @@ class CorpusPattern(Corpus):
 
     def _generate_entity_candidate(self) -> List[Dict[str, str]]:
         pass
+
+    @classmethod
+    def read_from_file(cls, data_file):
+        with open(data_file) as fd:
+            doc_list = read_markdown(fd.read())
+
+        return cls(doc_list)
+
+    def write_to_file(self, output_file):
+        group_by_intent = collections.defaultdict(list)
+        for doc in self:
+            group_by_intent[doc.intent].append(doc)
+
+        with open(output_file, "wt") as fd:
+            for intent, docs in group_by_intent.items():
+                fd.write("## {}\n".format(intent))
+
+                for doc in docs:
+                    fd.write("* {}\n".format(doc.convert_to_md()))
+
+                fd.write("\n")
